# Current and Future Features

## Schemes

Fetch checkers from more schemes, like:

- [x] file
- [x] asset in Python package
- [x] http(s)
- [ ] ...

## File types

File types which can be handled:

- [x] plain text (.bashrc, .env, ...)
- [x] json
- [x] yaml
- [x] toml
- [ ] ...

## Check types

The file can be checked for:

- [x] check key/value present
- [x] check key/value absent
- [x] check key/value matches regex
- [x] check lines present
- [x] check lines absent
- [x] use templates with variables
- [ ] schema compliance
- [ ] ...
